summaryrefslogtreecommitdiff
path: root/tools
diff options
context:
space:
mode:
authormattip <matti.picus@gmail.com>2020-07-10 15:35:29 +0300
committermattip <matti.picus@gmail.com>2020-07-10 15:35:29 +0300
commitfc9d862f0cec6d9dc83acef54a66732dfdb813a3 (patch)
tree369d7350a9203b7978eea5df9b5858cf65bb4234 /tools
parent58da484abf6f466a9e8bf55c188cb5b501d31ceb (diff)
downloadnumpy-fc9d862f0cec6d9dc83acef54a66732dfdb813a3.tar.gz
BLD: update cython to 0.29.21
Diffstat (limited to 'tools')
-rwxr-xr-xtools/cythonize.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/cythonize.py b/tools/cythonize.py
index 65b79f716..6cebf0f72 100755
--- a/tools/cythonize.py
+++ b/tools/cythonize.py
@@ -66,11 +66,11 @@ def process_pyx(fromfile, tofile):
# check the version, and invoke through python
from distutils.version import LooseVersion
# Cython 0.29.14 is required for Python 3.8 and there are
# other fixes in the 0.29 series that are needed even for earlier
# Python versions.
# Note: keep in sync with that in pyproject.toml
- required_version = LooseVersion('0.29.14')
+ required_version = LooseVersion('0.29.21')
if LooseVersion(cython_version) < required_version:
raise RuntimeError(f'Building {VENDOR} requires Cython >= {required_version}')
@@ -66,11 +66,11 @@ def process_pyx(fromfile, tofile):
# check the version, and invoke through python
from distutils.version import LooseVersion
- # Cython 0.29.14 is required for Python 3.8 and there are
+ # Cython 0.29.21 is required for Python 3.9 and there are
# other fixes in the 0.29 series that are needed even for earlier
# Python versions.